==> nextcloud-30.0.5.tgz: nextcloud/apps/app_api/l10n/lt_LT.js <==
OC.L10N.register(
    "app_api",
    {
    "Daemon config not found" : "Nerasta tarnybos konfigūracija",
    "Cancel" : "Atsisakyti",
    "Delete" : "Ištrinti",
    "Default" : "Numatytasis",
    "Edit" : "Taisyti",
    "Name" : "Vardas",
    "Host" : "Serveris",
    "Nextcloud URL" : "Nextcloud URL",
    "More info" : "Daugiau informacijos",
    "Enabled" : "Įjungta",
    "Network" : "Tinklas",
    "Confirm" : "Patvirtinti",
    "Save" : "Įrašyti",
    "Register" : "Registruotis",
    "Check connection" : "Tikrinti ryšį",
    "Update to {version}" : "Atnaujinti į versiją {version}",
    "Remove" : "Šalinti",
    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Ši programėlė neturi priskirtos žemiausios „Nextcloud“ versijos. Ateityje tai bus klaida.",
    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Ši programėlė neturi priskirtos aukščiausios „Nextcloud“ versijos. Ateityje tai bus klaida.",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "Ši programėlė negali būti įdiegta, nes nėra patenkintos žemiau išvardintos priklausomybės:",
    "View in store" : "Rodyti parduotuvėje",
    "Visit website" : "Aplankyti svetainę",
    "Report a bug" : "Pranešti apie klaidą",
    "User documentation" : "Naudotojo dokumentacija",
    "Admin documentation" : "Administratoriaus dokumentacija",
    "Developer documentation" : "Plėtotojo dokumentacija",
    "{license}-licensed" : "Licencijuota pagal {license}",
    "This app is supported via your current Nextcloud subscription." : "Ši programėlė yra palaikoma per jūsų esamą Nextcloud prenumeratą.",
    "Supported" : "Palaikoma",
    "Featured apps are developed by and within the community. They offer central functionality and are ready for production use." : "Siūlomos programėlės yra kuriamos bendruomenės viduje ir jas kuria bendruomenė. Šios programėlės siūlo svarbiausią funkcionalumą ir yra paruoštos kasdieniam naudojimui.",
    "Featured" : "Siūlomos",
    "Update to {update}" : "Atnaujinti į {update}",
    "Icon" : "Piktograma",
    "Version" : "Versija",
    "Daemon" : "Tarnyba",
    "Level" : "Lygmuo",
    "Actions" : "Veiksmai",
    "Results from other categories" : "Rezultatai iš kitų kategorijų",
    "_Update_::_Update all_" : ["Atnaujinti","Atnaujinti visas","Atnaujinti visas","Atnaujinti visas"],
    "Type" : "Tipas",
    "Display Name" : "Rodomas vardas",
    "Your apps" : "Jūsų programėlės",
    "Documentation" : "Dokumentacija",
    "Details" : "Išsamiau",
    "Changelog" : "Keitinių žurnalas",
    "by {author}\n{license}" : "pagal {author}\n{license}",
    "Active apps" : "Aktyvios programėlės",
    "Disabled apps" : "Išjungtos programėlės",
    "Updates" : "Atnaujinimai",
    "Featured apps" : "Siūlomos programėlės",
    "Supported apps" : "Palaikomos programėlės",
    "Enable" : "Aktyvuoti",
    "Disable" : "Išjungti",
    "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "Ši programėlė nėra pažymėta kaip suderinama su jūsų Nextcloud versija. Jei tęsite, vis tiek galėsite įdiegti programėlę. Turėkite omenyje, kad programėlė gali neveikti taip, kaip tikimasi.",
    "An error occurred during the request. Unable to proceed." : "Užklausos metu įvyko klaida. Nepavyksta tęsti.",
    "Error: This app cannot be enabled because it makes the server unstable" : "Klaida: Ši programėlė negali būti įjungta, nes ji neigiamai veikia serverio stabilumą"
},
"nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");

==> nextcloud-30.0.10.tgz: nextcloud/apps/app_api/l10n/lt_LT.js <==
OC.L10N.register(
    "app_api",
    {
    "Daemon config not found" : "Nerasta tarnybos konfigūracija",
    "Cancel" : "Atsisakyti",
    "Delete" : "Ištrinti",
    "Default" : "Numatytasis",
    "Edit" : "Taisyti",
    "Name" : "Pavadinimas",
    "Protocol" : "Protokolas",
    "Host" : "Serveris",
    "Nextcloud URL" : "Nextcloud URL",
    "Enabled" : "Įjungta",
    "More info" : "Daugiau informacijos",
    "Disabled" : "Išjungta",
    "Confirm" : "Patvirtinti",
    "Save" : "Įrašyti",
    "Register" : "Registruotis",
    "Check connection" : "Tikrinti ryšį",
    "{license}-licensed" : "Licencijuota pagal {license}",
    "Update to {version}" : "Atnaujinti į versiją {version}",
    "Remove" : "Šalinti",
    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Ši programėlė neturi priskirtos žemiausios „Nextcloud“ versijos. Ateityje tai bus klaida.",
    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Ši programėlė neturi priskirtos aukščiausios „Nextcloud“ versijos. Ateityje tai bus klaida.",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "Ši programėlė negali būti įdiegta, nes nėra patenkintos žemiau išvardintos priklausomybės:",
    "View in store" : "Rodyti parduotuvėje",
    "Visit website" : "Aplankyti svetainę",
    "Report a bug" : "Pranešti apie klaidą",
    "User documentation" : "Naudotojo dokumentacija",
    "Admin documentation" : "Administratoriaus dokumentacija",
    "Developer documentation" : "Plėtotojo dokumentacija",
    "This app is supported via your current Nextcloud subscription." : "Ši programėlė yra palaikoma per jūsų esamą Nextcloud prenumeratą.",
    "Supported" : "Palaikoma",
    "Featured apps are developed by and within the community. They offer central functionality and are ready for production use." : "Siūlomos programėlės yra kuriamos bendruomenės viduje ir jas kuria bendruomenė. Šios programėlės siūlo svarbiausią funkcionalumą ir yra paruoštos kasdieniam naudojimui.",
    "Featured" : "Siūlomos",
    "Update to {update}" : "Atnaujinti į {update}",
    "Icon" : "Piktograma",
    "Version" : "Versija",
    "Daemon" : "Tarnyba",
    "Level" : "Lygmuo",
    "Actions" : "Veiksmai",
    "Results from other categories" : "Rezultatai iš kitų kategorijų",
    "_Update_::_Update all_" : ["Atnaujinti","Atnaujinti visas","Atnaujinti visas","Atnaujinti visas"],
    "Type" : "Tipas",
    "Display Name" : "Rodomas vardas",
    "Network" : "Tinklas",
    "by {author}\n{license}" : "pagal {author}\n{license}",
    "Your apps" : "Jūsų programėlės",
    "Documentation" : "Dokumentacija",
    "Details" : "Išsamiau",
    "Changelog" : "Keitinių žurnalas",
    "Active apps" : "Aktyvios programėlės",
    "Disabled apps" : "Išjungtos programėlės",
    "Updates" : "Atnaujinimai",
    "Featured apps" : "Siūlomos programėlės",
    "Supported apps" : "Palaikomos programėlės",
    "Enable" : "Aktyvuoti",
    "Disable" : "Išjungti",
    "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "Ši programėlė nėra pažymėta kaip suderinama su jūsų Nextcloud versija. Jei tęsite, vis tiek galėsite įdiegti programėlę. Turėkite omenyje, kad programėlė gali neveikti taip, kaip tikimasi.",
    "An error occurred during the request. Unable to proceed." : "Užklausos metu įvyko klaida. Nepavyksta tęsti.",
    "The app has been enabled but needs to be updated." : "Programėlė įjungta, bet turi būti atnaujinta.",
    "Error: This app cannot be enabled because it makes the server unstable" : "Klaida: Ši programėlė negali būti įjungta, nes ji neigiamai veikia serverio stabilumą"
},
"nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");
